@@ -1,25 +1,23 @@
-from decimal import Decimal
-import sys
-
+from django.core.serializers.json import DjangoJSONEncoder
 from django.http import HttpResponse
 from django.utils import simplejson
-from django.core.mail import mail_admins
 from django.utils.encoding import force_unicode
 from django.utils.functional import Promise
 from django.utils.translation import ugettext as _
 from django.utils.cache import add_never_cache_headers
 from django.views.generic.base import TemplateView
 
+import logging
+logger = logging.getLogger(__name__)
 
-class DTEncoder(simplejson.JSONEncoder):
-    """Encodes django's lazy i18n strings and Decimals
+
+class LazyEncoder(DjangoJSONEncoder):
+    """Encodes django's lazy i18n strings
     """
     def default(self, obj):
         if isinstance(obj, Promise):
             return force_unicode(obj)
-        elif isinstance(obj, Decimal):
-            return force_unicode(obj)
-        return simplejson.JSONEncoder.default(self, obj)
+        return super(LazyEncoder, self).default(obj)
 
 
 class JSONResponseMixin(object):
@@ -34,8 +32,8 @@ class JSONResponseMixin(object):
         """ Construct an `HttpResponse` object.
         """
         response = HttpResponse(content,
-                            content_type='application/json',
-                            **httpresponse_kwargs)
+                                content_type='application/json',
+                                **httpresponse_kwargs)
         add_never_cache_headers(response)
         return response
 
@@ -59,31 +57,19 @@ class JSONResponseMixin(object):
             # Allow keyboard interrupts through for debugging.
             raise
         except Exception as e:
-            # Mail the admins with the error
-            exc_info = sys.exc_info()
-            subject = 'JSON view error: %s' % request.path
-            try:
-                request_repr = repr(request)
-            except Exception as exc:
-                request_repr = 'Request repr() unavailable'
-            import traceback
-            message = 'Traceback:\n%s\n\nRequest:\n%s' % (
-                '\n'.join(traceback.format_exception(*exc_info)),
-                request_repr,
-                )
-            mail_admins(subject, message, fail_silently=True)
+            logger.error('JSON view error: %s' % request.path, exc_info=True)
 
             # Come what may, we're returning JSON.
             if hasattr(e, 'message'):
                 msg = e.message
                 msg += str(e)
             else:
-                msg = _('Internal error')+': '+str(e)
+                msg = _('Internal error') + ': ' + str(e)
             response = {'result': 'error',
                         'text': msg}
 
-        json = simplejson.dumps(response, cls=DTEncoder)
-        return self.render_to_response(json) 
+        json = simplejson.dumps(response, cls=LazyEncoder)
+        return self.render_to_response(json)
 
 
 class JSONResponseView(JSONResponseMixin, TemplateView):
